@@ -116,49 +116,65 @@ __all__ = (
 ChangesetErrorInfoTypeDef = TypedDict(
     "ChangesetErrorInfoTypeDef",
     {
-        "errorMessage": NotRequired[str],
-        "errorCategory": NotRequired[ErrorCategoryType],
+        "errorMessage": str,
+        "errorCategory": ErrorCategoryType,
     },
+    total=False,
 )
 
 ChangesetSummaryTypeDef = TypedDict(
     "ChangesetSummaryTypeDef",
     {
-        "changesetId": NotRequired[str],
-        "changesetArn": NotRequired[str],
-        "datasetId": NotRequired[str],
-        "changeType": NotRequired[ChangeTypeType],
-        "sourceParams": NotRequired[Dict[str, str]],
-        "formatParams": NotRequired[Dict[str, str]],
-        "createTime": NotRequired[int],
-        "status": NotRequired[IngestionStatusType],
-        "errorInfo": NotRequired["ChangesetErrorInfoTypeDef"],
-        "activeUntilTimestamp": NotRequired[int],
-        "activeFromTimestamp": NotRequired[int],
-        "updatesChangesetId": NotRequired[str],
-        "updatedByChangesetId": NotRequired[str],
+        "changesetId": str,
+        "changesetArn": str,
+        "datasetId": str,
+        "changeType": ChangeTypeType,
+        "sourceParams": Dict[str, str],
+        "formatParams": Dict[str, str],
+        "createTime": int,
+        "status": IngestionStatusType,
+        "errorInfo": "ChangesetErrorInfoTypeDef",
+        "activeUntilTimestamp": int,
+        "activeFromTimestamp": int,
+        "updatesChangesetId": str,
+        "updatedByChangesetId": str,
     },
+    total=False,
 )
 
 ColumnDefinitionTypeDef = TypedDict(
     "ColumnDefinitionTypeDef",
     {
-        "dataType": NotRequired[ColumnDataTypeType],
-        "columnName": NotRequired[str],
-        "columnDescription": NotRequired[str],
+        "dataType": ColumnDataTypeType,
+        "columnName": str,
+        "columnDescription": str,
     },
+    total=False,
 )
 
-CreateChangesetRequestRequestTypeDef = TypedDict(
-    "CreateChangesetRequestRequestTypeDef",
+_RequiredCreateChangesetRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateChangesetRequestRequestTypeDef",
     {
         "datasetId": str,
         "changeType": ChangeTypeType,
         "sourceParams": Mapping[str, str],
         "formatParams": Mapping[str, str],
-        "clientToken": NotRequired[str],
     },
 )
+_OptionalCreateChangesetRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateChangesetRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class CreateChangesetRequestRequestTypeDef(
+    _RequiredCreateChangesetRequestRequestTypeDef, _OptionalCreateChangesetRequestRequestTypeDef
+):
+    pass
+
 
 CreateChangesetResponseTypeDef = TypedDict(
     "CreateChangesetResponseTypeDef",
@@ -169,18 +185,31 @@ CreateChangesetResponseTypeDef = TypedDict(
     },
 )
 
-CreateDataViewRequestRequestTypeDef = TypedDict(
-    "CreateDataViewRequestRequestTypeDef",
+_RequiredCreateDataViewRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateDataViewRequestRequestTypeDef",
     {
         "datasetId": str,
         "destinationTypeParams": "DataViewDestinationTypeParamsTypeDef",
-        "clientToken": NotRequired[str],
-        "autoUpdate": NotRequired[bool],
-        "sortColumns": NotRequired[Sequence[str]],
-        "partitionColumns": NotRequired[Sequence[str]],
-        "asOfTimestamp": NotRequired[int],
     },
 )
+_OptionalCreateDataViewRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateDataViewRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "autoUpdate": bool,
+        "sortColumns": Sequence[str],
+        "partitionColumns": Sequence[str],
+        "asOfTimestamp": int,
+    },
+    total=False,
+)
+
+
+class CreateDataViewRequestRequestTypeDef(
+    _RequiredCreateDataViewRequestRequestTypeDef, _OptionalCreateDataViewRequestRequestTypeDef
+):
+    pass
+
 
 CreateDataViewResponseTypeDef = TypedDict(
     "CreateDataViewResponseTypeDef",
@@ -191,19 +220,32 @@ CreateDataViewResponseTypeDef = TypedDict(
     },
 )
 
-CreateDatasetRequestRequestTypeDef = TypedDict(
-    "CreateDatasetRequestRequestTypeDef",
+_RequiredCreateDatasetRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateDatasetRequestRequestTypeDef",
     {
         "datasetTitle": str,
         "kind": DatasetKindType,
         "permissionGroupParams": "PermissionGroupParamsTypeDef",
-        "clientToken": NotRequired[str],
-        "datasetDescription": NotRequired[str],
-        "ownerInfo": NotRequired["DatasetOwnerInfoTypeDef"],
-        "alias": NotRequired[str],
-        "schemaDefinition": NotRequired["SchemaUnionTypeDef"],
     },
 )
+_OptionalCreateDatasetRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateDatasetRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "datasetDescription": str,
+        "ownerInfo": "DatasetOwnerInfoTypeDef",
+        "alias": str,
+        "schemaDefinition": "SchemaUnionTypeDef",
+    },
+    total=False,
+)
+
+
+class CreateDatasetRequestRequestTypeDef(
+    _RequiredCreateDatasetRequestRequestTypeDef, _OptionalCreateDatasetRequestRequestTypeDef
+):
+    pass
+
 
 CreateDatasetResponseTypeDef = TypedDict(
     "CreateDatasetResponseTypeDef",
@@ -213,15 +255,29 @@ CreateDatasetResponseTypeDef = TypedDict(
     },
 )
 
-CreatePermissionGroupRequestRequestTypeDef = TypedDict(
-    "CreatePermissionGroupRequestRequestTypeDef",
+_RequiredCreatePermissionGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredCreatePermissionGroupRequestRequestTypeDef",
     {
         "name": str,
         "applicationPermissions": Sequence[ApplicationPermissionType],
-        "description": NotRequired[str],
-        "clientToken": NotRequired[str],
     },
 )
+_OptionalCreatePermissionGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalCreatePermissionGroupRequestRequestTypeDef",
+    {
+        "description": str,
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class CreatePermissionGroupRequestRequestTypeDef(
+    _RequiredCreatePermissionGroupRequestRequestTypeDef,
+    _OptionalCreatePermissionGroupRequestRequestTypeDef,
+):
+    pass
+
 
 CreatePermissionGroupResponseTypeDef = TypedDict(
     "CreatePermissionGroupResponseTypeDef",
@@ -231,18 +287,31 @@ CreatePermissionGroupResponseTypeDef = TypedDict(
     },
 )
 
-CreateUserRequestRequestTypeDef = TypedDict(
-    "CreateUserRequestRequestTypeDef",
+_RequiredCreateUserRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateUserRequestRequestTypeDef",
     {
         "emailAddress": str,
         "type": UserTypeType,
-        "firstName": NotRequired[str],
-        "lastName": NotRequired[str],
-        "ApiAccess": NotRequired[ApiAccessType],
-        "apiAccessPrincipalArn": NotRequired[str],
-        "clientToken": NotRequired[str],
     },
 )
+_OptionalCreateUserRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateUserRequestRequestTypeDef",
+    {
+        "firstName": str,
+        "lastName": str,
+        "ApiAccess": ApiAccessType,
+        "apiAccessPrincipalArn": str,
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class CreateUserRequestRequestTypeDef(
+    _RequiredCreateUserRequestRequestTypeDef, _OptionalCreateUserRequestRequestTypeDef
+):
+    pass
+
 
 CreateUserResponseTypeDef = TypedDict(
     "CreateUserResponseTypeDef",
@@ -255,79 +324,110 @@ CreateUserResponseTypeDef = TypedDict(
 CredentialsTypeDef = TypedDict(
     "CredentialsTypeDef",
     {
-        "accessKeyId": NotRequired[str],
-        "secretAccessKey": NotRequired[str],
-        "sessionToken": NotRequired[str],
+        "accessKeyId": str,
+        "secretAccessKey": str,
+        "sessionToken": str,
     },
+    total=False,
 )
 
-DataViewDestinationTypeParamsTypeDef = TypedDict(
-    "DataViewDestinationTypeParamsTypeDef",
+_RequiredDataViewDestinationTypeParamsTypeDef = TypedDict(
+    "_RequiredDataViewDestinationTypeParamsTypeDef",
     {
         "destinationType": str,
-        "s3DestinationExportFileFormat": NotRequired[ExportFileFormatType],
-        "s3DestinationExportFileFormatOptions": NotRequired[Mapping[str, str]],
     },
 )
+_OptionalDataViewDestinationTypeParamsTypeDef = TypedDict(
+    "_OptionalDataViewDestinationTypeParamsTypeDef",
+    {
+        "s3DestinationExportFileFormat": ExportFileFormatType,
+        "s3DestinationExportFileFormatOptions": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class DataViewDestinationTypeParamsTypeDef(
+    _RequiredDataViewDestinationTypeParamsTypeDef, _OptionalDataViewDestinationTypeParamsTypeDef
+):
+    pass
+
 
 DataViewErrorInfoTypeDef = TypedDict(
     "DataViewErrorInfoTypeDef",
     {
-        "errorMessage": NotRequired[str],
-        "errorCategory": NotRequired[ErrorCategoryType],
+        "errorMessage": str,
+        "errorCategory": ErrorCategoryType,
     },
+    total=False,
 )
 
 DataViewSummaryTypeDef = TypedDict(
     "DataViewSummaryTypeDef",
     {
-        "dataViewId": NotRequired[str],
-        "dataViewArn": NotRequired[str],
-        "datasetId": NotRequired[str],
-        "asOfTimestamp": NotRequired[int],
-        "partitionColumns": NotRequired[List[str]],
-        "sortColumns": NotRequired[List[str]],
-        "status": NotRequired[DataViewStatusType],
-        "errorInfo": NotRequired["DataViewErrorInfoTypeDef"],
-        "destinationTypeProperties": NotRequired["DataViewDestinationTypeParamsTypeDef"],
-        "autoUpdate": NotRequired[bool],
-        "createTime": NotRequired[int],
-        "lastModifiedTime": NotRequired[int],
+        "dataViewId": str,
+        "dataViewArn": str,
+        "datasetId": str,
+        "asOfTimestamp": int,
+        "partitionColumns": List[str],
+        "sortColumns": List[str],
+        "status": DataViewStatusType,
+        "errorInfo": "DataViewErrorInfoTypeDef",
+        "destinationTypeProperties": "DataViewDestinationTypeParamsTypeDef",
+        "autoUpdate": bool,
+        "createTime": int,
+        "lastModifiedTime": int,
     },
+    total=False,
 )
 
 DatasetOwnerInfoTypeDef = TypedDict(
     "DatasetOwnerInfoTypeDef",
     {
-        "name": NotRequired[str],
-        "phoneNumber": NotRequired[str],
-        "email": NotRequired[str],
+        "name": str,
+        "phoneNumber": str,
+        "email": str,
     },
+    total=False,
 )
 
 DatasetTypeDef = TypedDict(
     "DatasetTypeDef",
     {
-        "datasetId": NotRequired[str],
-        "datasetArn": NotRequired[str],
-        "datasetTitle": NotRequired[str],
-        "kind": NotRequired[DatasetKindType],
-        "datasetDescription": NotRequired[str],
-        "ownerInfo": NotRequired["DatasetOwnerInfoTypeDef"],
-        "createTime": NotRequired[int],
-        "lastModifiedTime": NotRequired[int],
-        "schemaDefinition": NotRequired["SchemaUnionTypeDef"],
-        "alias": NotRequired[str],
+        "datasetId": str,
+        "datasetArn": str,
+        "datasetTitle": str,
+        "kind": DatasetKindType,
+        "datasetDescription": str,
+        "ownerInfo": "DatasetOwnerInfoTypeDef",
+        "createTime": int,
+        "lastModifiedTime": int,
+        "schemaDefinition": "SchemaUnionTypeDef",
+        "alias": str,
     },
+    total=False,
 )
 
-DeleteDatasetRequestRequestTypeDef = TypedDict(
-    "DeleteDatasetRequestRequestTypeDef",
+_RequiredDeleteDatasetRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteDatasetRequestRequestTypeDef",
     {
         "datasetId": str,
-        "clientToken": NotRequired[str],
     },
 )
+_OptionalDeleteDatasetRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteDatasetRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class DeleteDatasetRequestRequestTypeDef(
+    _RequiredDeleteDatasetRequestRequestTypeDef, _OptionalDeleteDatasetRequestRequestTypeDef
+):
+    pass
+
 
 DeleteDatasetResponseTypeDef = TypedDict(
     "DeleteDatasetResponseTypeDef",
@@ -337,13 +437,27 @@ DeleteDatasetResponseTypeDef = TypedDict(
     },
 )
 
-DeletePermissionGroupRequestRequestTypeDef = TypedDict(
-    "DeletePermissionGroupRequestRequestTypeDef",
+_RequiredDeletePermissionGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredDeletePermissionGroupRequestRequestTypeDef",
     {
         "permissionGroupId": str,
-        "clientToken": NotRequired[str],
     },
 )
+_OptionalDeletePermissionGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalDeletePermissionGroupRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class DeletePermissionGroupRequestRequestTypeDef(
+    _RequiredDeletePermissionGroupRequestRequestTypeDef,
+    _OptionalDeletePermissionGroupRequestRequestTypeDef,
+):
+    pass
+
 
 DeletePermissionGroupResponseTypeDef = TypedDict(
     "DeletePermissionGroupResponseTypeDef",
@@ -353,13 +467,26 @@ DeletePermissionGroupResponseTypeDef = TypedDict(
     },
 )
 
-DisableUserRequestRequestTypeDef = TypedDict(
-    "DisableUserRequestRequestTypeDef",
+_RequiredDisableUserRequestRequestTypeDef = TypedDict(
+    "_RequiredDisableUserRequestRequestTypeDef",
     {
         "userId": str,
-        "clientToken": NotRequired[str],
     },
 )
+_OptionalDisableUserRequestRequestTypeDef = TypedDict(
+    "_OptionalDisableUserRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class DisableUserRequestRequestTypeDef(
+    _RequiredDisableUserRequestRequestTypeDef, _OptionalDisableUserRequestRequestTypeDef
+):
+    pass
+
 
 DisableUserResponseTypeDef = TypedDict(
     "DisableUserResponseTypeDef",
@@ -369,13 +496,26 @@ DisableUserResponseTypeDef = TypedDict(
     },
 )
 
-EnableUserRequestRequestTypeDef = TypedDict(
-    "EnableUserRequestRequestTypeDef",
+_RequiredEnableUserRequestRequestTypeDef = TypedDict(
+    "_RequiredEnableUserRequestRequestTypeDef",
     {
         "userId": str,
-        "clientToken": NotRequired[str],
     },
 )
+_OptionalEnableUserRequestRequestTypeDef = TypedDict(
+    "_OptionalEnableUserRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class EnableUserRequestRequestTypeDef(
+    _RequiredEnableUserRequestRequestTypeDef, _OptionalEnableUserRequestRequestTypeDef
+):
+    pass
+
 
 EnableUserResponseTypeDef = TypedDict(
     "EnableUserResponseTypeDef",
@@ -464,13 +604,27 @@ GetDatasetResponseTypeDef = TypedDict(
     },
 )
 
-GetProgrammaticAccessCredentialsRequestRequestTypeDef = TypedDict(
-    "GetProgrammaticAccessCredentialsRequestRequestTypeDef",
+_RequiredGetProgrammaticAccessCredentialsRequestRequestTypeDef = TypedDict(
+    "_RequiredGetProgrammaticAccessCredentialsRequestRequestTypeDef",
     {
         "environmentId": str,
-        "durationInMinutes": NotRequired[int],
     },
 )
+_OptionalGetProgrammaticAccessCredentialsRequestRequestTypeDef = TypedDict(
+    "_OptionalGetProgrammaticAccessCredentialsRequestRequestTypeDef",
+    {
+        "durationInMinutes": int,
+    },
+    total=False,
+)
+
+
+class GetProgrammaticAccessCredentialsRequestRequestTypeDef(
+    _RequiredGetProgrammaticAccessCredentialsRequestRequestTypeDef,
+    _OptionalGetProgrammaticAccessCredentialsRequestRequestTypeDef,
+):
+    pass
+
 
 GetProgrammaticAccessCredentialsResponseTypeDef = TypedDict(
     "GetProgrammaticAccessCredentialsResponseTypeDef",
@@ -511,8 +665,9 @@ GetUserResponseTypeDef = TypedDict(
 GetWorkingLocationRequestRequestTypeDef = TypedDict(
     "GetWorkingLocationRequestRequestTypeDef",
     {
-        "locationType": NotRequired[locationTypeType],
+        "locationType": locationTypeType,
     },
+    total=False,
 )
 
 GetWorkingLocationResponseTypeDef = TypedDict(
@@ -525,22 +680,49 @@ GetWorkingLocationResponseTypeDef = TypedDict(
     },
 )
 
-ListChangesetsRequestListChangesetsPaginateTypeDef = TypedDict(
-    "ListChangesetsRequestListChangesetsPaginateTypeDef",
+_RequiredListChangesetsRequestListChangesetsPaginateTypeDef = TypedDict(
+    "_RequiredListChangesetsRequestListChangesetsPaginateTypeDef",
     {
         "datasetId": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListChangesetsRequestListChangesetsPaginateTypeDef = TypedDict(
+    "_OptionalListChangesetsRequestListChangesetsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListChangesetsRequestRequestTypeDef = TypedDict(
-    "ListChangesetsRequestRequestTypeDef",
+
+class ListChangesetsRequestListChangesetsPaginateTypeDef(
+    _RequiredListChangesetsRequestListChangesetsPaginateTypeDef,
+    _OptionalListChangesetsRequestListChangesetsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListChangesetsRequestRequestTypeDef = TypedDict(
+    "_RequiredListChangesetsRequestRequestTypeDef",
     {
         "datasetId": str,
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
     },
 )
+_OptionalListChangesetsRequestRequestTypeDef = TypedDict(
+    "_OptionalListChangesetsRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListChangesetsRequestRequestTypeDef(
+    _RequiredListChangesetsRequestRequestTypeDef, _OptionalListChangesetsRequestRequestTypeDef
+):
+    pass
+
 
 ListChangesetsResponseTypeDef = TypedDict(
     "ListChangesetsResponseTypeDef",
@@ -551,22 +733,49 @@ ListChangesetsResponseTypeDef = TypedDict(
     },
 )
 
-ListDataViewsRequestListDataViewsPaginateTypeDef = TypedDict(
-    "ListDataViewsRequestListDataViewsPaginateTypeDef",
+_RequiredListDataViewsRequestListDataViewsPaginateTypeDef = TypedDict(
+    "_RequiredListDataViewsRequestListDataViewsPaginateTypeDef",
     {
         "datasetId": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListDataViewsRequestListDataViewsPaginateTypeDef = TypedDict(
+    "_OptionalListDataViewsRequestListDataViewsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListDataViewsRequestRequestTypeDef = TypedDict(
-    "ListDataViewsRequestRequestTypeDef",
+
+class ListDataViewsRequestListDataViewsPaginateTypeDef(
+    _RequiredListDataViewsRequestListDataViewsPaginateTypeDef,
+    _OptionalListDataViewsRequestListDataViewsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListDataViewsRequestRequestTypeDef = TypedDict(
+    "_RequiredListDataViewsRequestRequestTypeDef",
     {
         "datasetId": str,
-        "nextToken": NotRequired[str],
-        "maxResults": NotRequired[int],
     },
 )
+_OptionalListDataViewsRequestRequestTypeDef = TypedDict(
+    "_OptionalListDataViewsRequestRequestTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
+
+class ListDataViewsRequestRequestTypeDef(
+    _RequiredListDataViewsRequestRequestTypeDef, _OptionalListDataViewsRequestRequestTypeDef
+):
+    pass
+
 
 ListDataViewsResponseTypeDef = TypedDict(
     "ListDataViewsResponseTypeDef",
@@ -580,16 +789,18 @@ ListDataViewsResponseTypeDef = TypedDict(
 ListDatasetsRequestListDatasetsPaginateTypeDef = TypedDict(
     "ListDatasetsRequestListDatasetsPaginateTypeDef",
     {
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListDatasetsRequestRequestTypeDef = TypedDict(
     "ListDatasetsRequestRequestTypeDef",
     {
-        "nextToken": NotRequired[str],
-        "maxResults": NotRequired[int],
+        "nextToken": str,
+        "maxResults": int,
     },
+    total=False,
 )
 
 ListDatasetsResponseTypeDef = TypedDict(
@@ -604,17 +815,32 @@ ListDatasetsResponseTypeDef = TypedDict(
 ListPermissionGroupsRequestListPermissionGroupsPaginateTypeDef = TypedDict(
     "ListPermissionGroupsRequestListPermissionGroupsPaginateTypeDef",
     {
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
-ListPermissionGroupsRequestRequestTypeDef = TypedDict(
-    "ListPermissionGroupsRequestRequestTypeDef",
+_RequiredListPermissionGroupsRequestRequestTypeDef = TypedDict(
+    "_RequiredListPermissionGroupsRequestRequestTypeDef",
     {
         "maxResults": int,
-        "nextToken": NotRequired[str],
     },
 )
+_OptionalListPermissionGroupsRequestRequestTypeDef = TypedDict(
+    "_OptionalListPermissionGroupsRequestRequestTypeDef",
+    {
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListPermissionGroupsRequestRequestTypeDef(
+    _RequiredListPermissionGroupsRequestRequestTypeDef,
+    _OptionalListPermissionGroupsRequestRequestTypeDef,
+):
+    pass
+
 
 ListPermissionGroupsResponseTypeDef = TypedDict(
     "ListPermissionGroupsResponseTypeDef",
@@ -628,17 +854,31 @@ ListPermissionGroupsResponseTypeDef = TypedDict(
 ListUsersRequestListUsersPaginateTypeDef = TypedDict(
     "ListUsersRequestListUsersPaginateTypeDef",
     {
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
-ListUsersRequestRequestTypeDef = TypedDict(
-    "ListUsersRequestRequestTypeDef",
+_RequiredListUsersRequestRequestTypeDef = TypedDict(
+    "_RequiredListUsersRequestRequestTypeDef",
     {
         "maxResults": int,
-        "nextToken": NotRequired[str],
     },
 )
+_OptionalListUsersRequestRequestTypeDef = TypedDict(
+    "_OptionalListUsersRequestRequestTypeDef",
+    {
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListUsersRequestRequestTypeDef(
+    _RequiredListUsersRequestRequestTypeDef, _OptionalListUsersRequestRequestTypeDef
+):
+    pass
+
 
 ListUsersResponseTypeDef = TypedDict(
     "ListUsersResponseTypeDef",
@@ -652,39 +892,55 @@ ListUsersResponseTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
 PermissionGroupParamsTypeDef = TypedDict(
     "PermissionGroupParamsTypeDef",
     {
-        "permissionGroupId": NotRequired[str],
-        "datasetPermissions": NotRequired[Sequence["ResourcePermissionTypeDef"]],
+        "permissionGroupId": str,
+        "datasetPermissions": Sequence["ResourcePermissionTypeDef"],
     },
+    total=False,
 )
 
 PermissionGroupTypeDef = TypedDict(
     "PermissionGroupTypeDef",
     {
-        "permissionGroupId": NotRequired[str],
-        "name": NotRequired[str],
-        "description": NotRequired[str],
-        "applicationPermissions": NotRequired[List[ApplicationPermissionType]],
-        "createTime": NotRequired[int],
-        "lastModifiedTime": NotRequired[int],
+        "permissionGroupId": str,
+        "name": str,
+        "description": str,
+        "applicationPermissions": List[ApplicationPermissionType],
+        "createTime": int,
+        "lastModifiedTime": int,
     },
+    total=False,
 )
 
-ResetUserPasswordRequestRequestTypeDef = TypedDict(
-    "ResetUserPasswordRequestRequestTypeDef",
+_RequiredResetUserPasswordRequestRequestTypeDef = TypedDict(
+    "_RequiredResetUserPasswordRequestRequestTypeDef",
     {
         "userId": str,
-        "clientToken": NotRequired[str],
     },
 )
+_OptionalResetUserPasswordRequestRequestTypeDef = TypedDict(
+    "_OptionalResetUserPasswordRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class ResetUserPasswordRequestRequestTypeDef(
+    _RequiredResetUserPasswordRequestRequestTypeDef, _OptionalResetUserPasswordRequestRequestTypeDef
+):
+    pass
+
 
 ResetUserPasswordResponseTypeDef = TypedDict(
     "ResetUserPasswordResponseTypeDef",
@@ -698,8 +954,9 @@ ResetUserPasswordResponseTypeDef = TypedDict(
 ResourcePermissionTypeDef = TypedDict(
     "ResourcePermissionTypeDef",
     {
-        "permission": NotRequired[str],
+        "permission": str,
     },
+    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -716,28 +973,43 @@ ResponseMetadataTypeDef = TypedDict(
 SchemaDefinitionTypeDef = TypedDict(
     "SchemaDefinitionTypeDef",
     {
-        "columns": NotRequired[Sequence["ColumnDefinitionTypeDef"]],
-        "primaryKeyColumns": NotRequired[Sequence[str]],
+        "columns": Sequence["ColumnDefinitionTypeDef"],
+        "primaryKeyColumns": Sequence[str],
     },
+    total=False,
 )
 
 SchemaUnionTypeDef = TypedDict(
     "SchemaUnionTypeDef",
     {
-        "tabularSchemaConfig": NotRequired["SchemaDefinitionTypeDef"],
+        "tabularSchemaConfig": "SchemaDefinitionTypeDef",
     },
+    total=False,
 )
 
-UpdateChangesetRequestRequestTypeDef = TypedDict(
-    "UpdateChangesetRequestRequestTypeDef",
+_RequiredUpdateChangesetRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateChangesetRequestRequestTypeDef",
     {
         "datasetId": str,
         "changesetId": str,
         "sourceParams": Mapping[str, str],
         "formatParams": Mapping[str, str],
-        "clientToken": NotRequired[str],
     },
 )
+_OptionalUpdateChangesetRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateChangesetRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class UpdateChangesetRequestRequestTypeDef(
+    _RequiredUpdateChangesetRequestRequestTypeDef, _OptionalUpdateChangesetRequestRequestTypeDef
+):
+    pass
+
 
 UpdateChangesetResponseTypeDef = TypedDict(
     "UpdateChangesetResponseTypeDef",
@@ -748,18 +1020,31 @@ UpdateChangesetResponseTypeDef = TypedDict(
     },
 )
 
-UpdateDatasetRequestRequestTypeDef = TypedDict(
-    "UpdateDatasetRequestRequestTypeDef",
+_RequiredUpdateDatasetRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateDatasetRequestRequestTypeDef",
     {
         "datasetId": str,
         "datasetTitle": str,
         "kind": DatasetKindType,
-        "clientToken": NotRequired[str],
-        "datasetDescription": NotRequired[str],
-        "alias": NotRequired[str],
-        "schemaDefinition": NotRequired["SchemaUnionTypeDef"],
     },
 )
+_OptionalUpdateDatasetRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateDatasetRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "datasetDescription": str,
+        "alias": str,
+        "schemaDefinition": "SchemaUnionTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateDatasetRequestRequestTypeDef(
+    _RequiredUpdateDatasetRequestRequestTypeDef, _OptionalUpdateDatasetRequestRequestTypeDef
+):
+    pass
+
 
 UpdateDatasetResponseTypeDef = TypedDict(
     "UpdateDatasetResponseTypeDef",
@@ -769,16 +1054,30 @@ UpdateDatasetResponseTypeDef = TypedDict(
     },
 )
 
-UpdatePermissionGroupRequestRequestTypeDef = TypedDict(
-    "UpdatePermissionGroupRequestRequestTypeDef",
+_RequiredUpdatePermissionGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdatePermissionGroupRequestRequestTypeDef",
     {
         "permissionGroupId": str,
-        "name": NotRequired[str],
-        "description": NotRequired[str],
-        "applicationPermissions": NotRequired[Sequence[ApplicationPermissionType]],
-        "clientToken": NotRequired[str],
     },
 )
+_OptionalUpdatePermissionGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdatePermissionGroupRequestRequestTypeDef",
+    {
+        "name": str,
+        "description": str,
+        "applicationPermissions": Sequence[ApplicationPermissionType],
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class UpdatePermissionGroupRequestRequestTypeDef(
+    _RequiredUpdatePermissionGroupRequestRequestTypeDef,
+    _OptionalUpdatePermissionGroupRequestRequestTypeDef,
+):
+    pass
+
 
 UpdatePermissionGroupResponseTypeDef = TypedDict(
     "UpdatePermissionGroupResponseTypeDef",
@@ -788,18 +1087,31 @@ UpdatePermissionGroupResponseTypeDef = TypedDict(
     },
 )
 
-UpdateUserRequestRequestTypeDef = TypedDict(
-    "UpdateUserRequestRequestTypeDef",
+_RequiredUpdateUserRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateUserRequestRequestTypeDef",
     {
         "userId": str,
-        "type": NotRequired[UserTypeType],
-        "firstName": NotRequired[str],
-        "lastName": NotRequired[str],
-        "apiAccess": NotRequired[ApiAccessType],
-        "apiAccessPrincipalArn": NotRequired[str],
-        "clientToken": NotRequired[str],
     },
 )
+_OptionalUpdateUserRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateUserRequestRequestTypeDef",
+    {
+        "type": UserTypeType,
+        "firstName": str,
+        "lastName": str,
+        "apiAccess": ApiAccessType,
+        "apiAccessPrincipalArn": str,
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class UpdateUserRequestRequestTypeDef(
+    _RequiredUpdateUserRequestRequestTypeDef, _OptionalUpdateUserRequestRequestTypeDef
+):
+    pass
+
 
 UpdateUserResponseTypeDef = TypedDict(
     "UpdateUserResponseTypeDef",
@@ -812,18 +1124,19 @@ UpdateUserResponseTypeDef = TypedDict(
 UserTypeDef = TypedDict(
     "UserTypeDef",
     {
-        "userId": NotRequired[str],
-        "status": NotRequired[UserStatusType],
-        "firstName": NotRequired[str],
-        "lastName": NotRequired[str],
-        "emailAddress": NotRequired[str],
-        "type": NotRequired[UserTypeType],
-        "apiAccess": NotRequired[ApiAccessType],
-        "apiAccessPrincipalArn": NotRequired[str],
-        "createTime": NotRequired[int],
-        "lastEnabledTime": NotRequired[int],
-        "lastDisabledTime": NotRequired[int],
-        "lastModifiedTime": NotRequired[int],
-        "lastLoginTime": NotRequired[int],
+        "userId": str,
+        "status": UserStatusType,
+        "firstName": str,
+        "lastName": str,
+        "emailAddress": str,
+        "type": UserTypeType,
+        "apiAccess": ApiAccessType,
+        "apiAccessPrincipalArn": str,
+        "createTime": int,
+        "lastEnabledTime": int,
+        "lastDisabledTime": int,
+        "lastModifiedTime": int,
+        "lastLoginTime": int,
     },
+    total=False,
 )
